==> lapmix_1.16.0.zip: lapmix/doc/lapmix-example.R <==
###################################################
### chunk number 1: library
###################################################
#line 17 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
library(lapmix)


###################################################
### chunk number 2: sim
###################################################
#line 23 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
set.seed(1011)
G <- 3000
Y <- NULL
sigma_sq <- 1/rgamma(G, shape=2.8, scale=0.04)
mu <- rexp(G, rate=1/(sigma_sq*1.2))-rexp(G, rate=1/(sigma_sq*1.2))
is.diff <- sample(c(0,1), replace=TRUE, prob=c(0.9,0.1), size=G)
mu <- mu*is.diff
for(g in 1:G)
	Y <- rbind(Y, rnorm(4,mu[g], sd=sqrt(sigma_sq[g])))


###################################################
### chunk number 3: fit
###################################################
#line 37 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
res <- lapmix.Fit(Y)


###################################################
### chunk number 4: estimates
###################################################
#line 43 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
res$estimates


###################################################
### chunk number 5: table
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
m <- 12
laptopTable(res, m)


###################################################
### chunk number 6: 
###################################################
#line 58 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
lap.volcanoplot(res)


###################################################
### chunk number 7: fitasym
###################################################
#line 66 "E:/biocbld/bbs-2.7-bioc/tmpdir/Rtmp6szgbW/R.INSTALL732b68e8/lapmix/inst/doc/lapmix-example.Rnw"
res2 <- lapmix.Fit(Y, asym=TRUE)
res2$estimates

==> lapmix_1.18.0.zip: lapmix/doc/lapmix-example.R <==
###################################################
### chunk number 1: library
###################################################
#line 17 "lapmix-example.Rnw"
library(lapmix)


###################################################
### chunk number 2: sim
###################################################
#line 23 "lapmix-example.Rnw"
set.seed(1011)
G <- 3000
Y <- NULL
sigma_sq <- 1/rgamma(G, shape=2.8, scale=0.04)
mu <- rexp(G, rate=1/(sigma_sq*1.2))-rexp(G, rate=1/(sigma_sq*1.2))
is.diff <- sample(c(0,1), replace=TRUE, prob=c(0.9,0.1), size=G)
mu <- mu*is.diff
for(g in 1:G)
	Y <- rbind(Y, rnorm(4,mu[g], sd=sqrt(sigma_sq[g])))


###################################################
### chunk number 3: fit
###################################################
#line 37 "lapmix-example.Rnw"
res <- lapmix.Fit(Y)


###################################################
### chunk number 4: estimates
###################################################
#line 43 "lapmix-example.Rnw"
res$estimates


###################################################
### chunk number 5: table
###################################################
#line 50 "lapmix-example.Rnw"
m <- 12
laptopTable(res, m)


###################################################
### chunk number 6: 
###################################################
#line 58 "lapmix-example.Rnw"
lap.volcanoplot(res)


###################################################
### chunk number 7: fitasym
###################################################
#line 66 "lapmix-example.Rnw"
res2 <- lapmix.Fit(Y, asym=TRUE)
res2$estimates
